@@ -23,14 +23,13 @@
 
 from __future__ import print_function
 
-import errno
 import io
 import os
 import re
 import tokenize
 
 
-__version__ = '0.2.7'
+__version__ = '0.2.8'
 
 
 try:
@@ -48,6 +47,9 @@ def format_code(source,
     Wrap summary lines if summary_wrap_length is greater than 0.
 
     """
+    if not source:
+        return source
+
     sio = io.StringIO(source)
     formatted = ''
     previous_token_string = ''
@@ -187,8 +189,16 @@ def split_summary_and_description(contents):
         split = re.split(r'\.\s', string=contents, maxsplit=1)
         if len(split) == 2:
             return (split[0].strip() + '.', split[1].strip())
-        else:
-            return (split[0].strip(), unicode())
+
+        # Break on first bullet-list-like text.
+        for token in ['    @',
+                      '    -',
+                      '    *']:
+            split = contents.split(token, 1)
+            if len(split) == 2:
+                return (split[0].strip(), (token + split[1]).strip())
+
+    return (split[0].strip(), unicode())
 
 
 def strip_docstring(docstring):
@@ -207,7 +217,7 @@ def normalize_summary(summary):
     summary = re.sub(r'\s*\n\s*', ' ', summary.rstrip())
 
     # Add period at end of sentence
-    if summary and summary[-1].isalnum():
+    if summary and (summary[-1].isalnum() or summary[-1] in ['"', "'"]):
         summary += '.'
 
     return summary
@@ -314,6 +324,4 @@ def main(argv, standard_out, standard_error):
             try:
                 format_file(name, args=args, standard_out=standard_out)
             except IOError as exception:
-                if exception.errno == errno.EPIPE:
-                    return
-                print(exception, file=standard_error)
+                print(unicode(exception), file=standard_error)
